@@ -14,6 +14,16 @@ database = SQLAlchemy()
 flask_bcrypt = Bcrypt()
 config = {}
 
+authorizations = {
+    'Basic Auth': {
+        'type': 'apiKey',
+        'in': 'header',
+        'name': 'Authorization'
+    },
+}
+
+
+
 class Api():
     app = None
     db = None
@@ -29,8 +39,9 @@ class Api():
         self.flask_bcrypt = Bcrypt()
         self.app_config = app_config
         self.api = ApiRestplus(self.app,
+            ui=app_config["DOC_UI"] if "DOC_UI" in app_config else True,
             security='Basic Auth',
-            #authorizations=AUTHORIZATIONS,
+            authorizations=authorizations,
             title='FLASK RESTPLUS API BOILER-PLATE WITH JWT',
             version='1.0',
             description='a boilerplate for flask restplus web service',
