@@ -1,6 +1,10 @@
 import os
 from flask_migrate import Migrate, MigrateCommand
 from flask_script import Manager
+from .api import database as db
+
+from dotenv import load_dotenv
+load_dotenv()
 
 application = None
 migrate = None
